@@ -1,5 +1,5 @@
-#ifndef _SHA256_SHANI_H_
-#define _SHA256_SHANI_H_
+#ifndef SHA256_SHANI_H_
+#define SHA256_SHANI_H_
 
 #include <stdint.h>
 
@@ -10,8 +10,12 @@
  * instructions, and should only be used if CPUSUPPORT_X86_SHANI and _SSSE3
  * are defined and cpusupport_x86_shani() and _ssse3() return nonzero.
  */
-void
-SHA256_Transform_shani(uint32_t[static restrict 8],
+#ifdef POSIXFAIL_ABSTRACT_DECLARATOR
+void SHA256_Transform_shani(uint32_t state[static restrict 8],
+    const uint8_t block[static restrict 64]);
+#else
+void SHA256_Transform_shani(uint32_t[static restrict 8],
     const uint8_t[static restrict 64]);
+#endif
 
-#endif /* !_SHA256_SHANI_H_ */
+#endif /* !SHA256_SHANI_H_ */
