@@ -25,7 +25,7 @@ int entropy_read_fill(struct entropy_read_cookie *, uint8_t *, size_t);
  * entropy_read_done(er):
  * Release any resources used by ${er}.
  */
-int entropy_read_done(struct entropy_read_cookie * er);
+int entropy_read_done(struct entropy_read_cookie *);
 
 /**
  * entropy_read(buf, buflen):
