@@ -8,7 +8,7 @@ decrypted_file="${s_basename}-attempt.txt"
 
 scenario_cmd() {
 	# Encrypt a file.  Use --passphrase dev:stdin-once instead of -P.
-	setup_check_variables "scrypt enc"
+	setup_check "scrypt enc"
 	(
 		echo "${password}" | ${c_valgrind_cmd} "${bindir}/scrypt" \
 		    enc --passphrase dev:stdin-once -t 1		\
@@ -20,12 +20,12 @@ scenario_cmd() {
 	# We cannot check against the "reference" encrypted file, because
 	# encrypted files include random salt.  If successful, don't delete
 	# ${encrypted_file} yet; we need it for the next test.
-	setup_check_variables "scrypt enc random salt"
+	setup_check "scrypt enc random salt"
 	cmp -s "${encrypted_file}" "${reference_file}"
 	expected_exitcode 1 $? > "${c_exitfile}"
 
 	# Decrypt the file we just encrypted.
-	setup_check_variables "scrypt enc decrypt"
+	setup_check "scrypt enc decrypt"
 	(
 		echo "${password}" | ${c_valgrind_cmd} "${bindir}/scrypt" \
 		    dec -P "${encrypted_file}" "${decrypted_file}"
@@ -33,7 +33,7 @@ scenario_cmd() {
 	)
 
 	# The decrypted file should match the reference.
-	setup_check_variables "scrypt enc decrypt output against reference"
+	setup_check "scrypt enc decrypt output against reference"
 	cmp -s "${decrypted_file}" "${reference_file}"
 	echo $? > "${c_exitfile}"
 }
