@@ -9,7 +9,7 @@ non_encoded_file_output="${s_basename}-nonfile.txt"
 scenario_cmd() {
 	# Attempt to decrypt a non-scrypt-encoded file.
 	# We want this command to fail with 1.
-	setup_check_variables "scrypt dec non-scrypt"
+	setup_check "scrypt dec non-scrypt"
 	(
 		echo "" | ${c_valgrind_cmd} "${bindir}/scrypt"		\
 		    dec -P "${non_encoded_file}"			\
@@ -19,13 +19,13 @@ scenario_cmd() {
 	)
 
 	# We should have received an error message.
-	setup_check_variables "scrypt dec non-scrypt error"
+	setup_check "scrypt dec non-scrypt error"
 	grep -q "scrypt: Input is not valid scrypt-encrypted block" \
 	    "${non_encoded_file_stderr}"
 	echo "$?" > "${c_exitfile}"
 
 	# We should not have created a file.
-	setup_check_variables "scrypt dec non-scrypt no file"
+	setup_check "scrypt dec non-scrypt no file"
 	if [ -e "${non_encoded_file_output}" ]; then
 		echo "1"
 	else
